@@ -1,11 +1,11 @@
 ##############################################################################
 # Net::Twitter - Perl OO interface to www.twitter.com
-# v1.22
-# Copyright (c) 2008 Chris Thompson
+# v1.23
+# Copyright (c) 2009 Chris Thompson
 ##############################################################################
 
 package Net::Twitter;
-$VERSION = "1.22";
+$VERSION = "1.23";
 use warnings;
 use strict;
 
@@ -113,8 +113,8 @@ sub public_timeline {
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub friends_timeline {
@@ -138,11 +138,12 @@ sub friends_timeline {
           ( defined $args->{count} ) ? "count=" . $args->{count} . "&" : "";
         $url .= ( defined $args->{page} ) ? "page=" . $args->{page} : "";
     }
+    
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub user_timeline {
@@ -170,9 +171,8 @@ sub user_timeline {
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub show_status {
@@ -181,9 +181,8 @@ sub show_status {
     my $req = $self->{ua}->get( $self->{apiurl} . "/statuses/show/$id.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update {
@@ -195,8 +194,8 @@ sub update {
       $self->{ua}->post( $self->{apiurl} . "/statuses/update.json", $args );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update_twittervision {
@@ -232,8 +231,8 @@ sub replies {
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub destroy_status {
@@ -243,8 +242,8 @@ sub destroy_status {
       $self->{ua}->post( $self->{apiurl} . "/statuses/destroy/$id.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 ########################################################################
@@ -254,7 +253,7 @@ sub destroy_status {
 sub friends {
     my ( $self, $args ) = @_;
     $args = { id => $args } unless ref($args);
-
+    
     my $url = $self->{apiurl} . "/statuses/friends";
     $url .= ( defined $args->{id} )    ? "/" . $args->{id} . ".json" : ".json";
     $url .= ( defined $args->{page} )  ? "?page=" . $args->{page}    : "";
@@ -263,9 +262,8 @@ sub friends {
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub followers {
@@ -280,14 +278,12 @@ sub followers {
     }
 
     $url =~ s/(.*)&$/$1/;
-    print $url;
 
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub show_user {
@@ -341,9 +337,8 @@ sub direct_messages {
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub sent_direct_messages {
@@ -364,9 +359,8 @@ sub sent_direct_messages {
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub new_direct_message {
@@ -376,9 +370,8 @@ sub new_direct_message {
       $self->{ua}->post( $self->{apiurl} . "/direct_messages/new.json", $args );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub destroy_direct_message {
@@ -389,9 +382,8 @@ sub destroy_direct_message {
       ->post( $self->{apiurl} . "/direct_messages/destroy/$id.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 ########################################################################
@@ -423,9 +415,8 @@ sub create_friend {
     }
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub destroy_friend {
@@ -435,9 +426,8 @@ sub destroy_friend {
       $self->{ua}->post( $self->{apiurl} . "/friendships/destroy/$id.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub relationship_exists {
@@ -465,9 +455,8 @@ sub verify_credentials {
       $self->{ua}->get( $self->{apiurl} . "/account/verify_credentials.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub end_session {
@@ -476,9 +465,8 @@ sub end_session {
     my $req = $self->{ua}->post( $self->{apiurl} . "/account/end_session" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update_location {
@@ -490,9 +478,8 @@ sub update_location {
 
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update_profile_colors {
@@ -504,9 +491,8 @@ sub update_profile_colors {
 
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update_profile_image {
@@ -518,9 +504,8 @@ sub update_profile_image {
 
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update_profile_background_image {
@@ -533,9 +518,8 @@ sub update_profile_background_image {
 
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update_delivery_device {
@@ -548,9 +532,8 @@ sub update_delivery_device {
 
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub rate_limit_status {
@@ -561,9 +544,8 @@ sub rate_limit_status {
 
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub update_profile {
@@ -575,9 +557,8 @@ sub update_profile {
 
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 ########################################################################
@@ -592,10 +573,8 @@ sub favorites {
     my $req = $self->{ua}->get($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-
-    $self->{response_error} = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub create_favorite {
@@ -605,10 +584,8 @@ sub create_favorite {
     my $req = $self->{ua}->post($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-
-    $self->{response_error} = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub destroy_favorite {
@@ -618,10 +595,8 @@ sub destroy_favorite {
     my $req = $self->{ua}->post($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-
-    $self->{response_error} = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 ########################################################################
@@ -636,10 +611,8 @@ sub enable_notifications {
     my $req = $self->{ua}->post($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-
-    $self->{response_error} = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub disable_notifications {
@@ -649,10 +622,8 @@ sub disable_notifications {
     my $req = $self->{ua}->post($url);
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-
-    $self->{response_error} = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 ########################################################################
@@ -665,9 +636,8 @@ sub create_block {
     my $req = $self->{ua}->post( $self->{apiurl} . "/blocks/create/$id.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub destroy_block {
@@ -676,9 +646,8 @@ sub destroy_block {
     my $req = $self->{ua}->post( $self->{apiurl} . "/blocks/destroy/$id.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 ########################################################################
@@ -691,9 +660,8 @@ sub test {
     my $req = $self->{ua}->get( $self->{apiurl} . "/help/test.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 sub downtime_schedule {
@@ -703,9 +671,8 @@ sub downtime_schedule {
       $self->{ua}->get( $self->{apiurl} . "/help/downtime_schedule.json" );
     $self->{response_code}    = $req->code;
     $self->{response_message} = $req->message;
-    $self->{response_error}   = JSON::Any->jsonToObj( $req->content );
-    return ( $req->is_success ) ? $self->{response_error} : undef;
-
+    $self->{response_error}   = $req->content;
+    return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;
 }
 
 1;
@@ -717,7 +684,7 @@ Net::Twitter - Perl interface to twitter.com
 
 =head1 VERSION
 
-This document describes Net::Twitter version 1.22
+This document describes Net::Twitter version 1.23
 
 =head1 SYNOPSIS
 
@@ -1520,6 +1487,9 @@ Please report any bugs or feature requests to
 C<bug-net-twitter@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
+You can also join the Net::Twitter IRC channel at irc://irc.perl.org/net-twitter
+ 
+You can track Net::Twitter development at http://github.com/ct/net-twitter/tree/master
 
 =head1 AUTHOR
 
@@ -1530,7 +1500,7 @@ ups to Chris "perigrin" Prather for that.
        
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2008, Chris Thompson <cpan@cthompson.com>. All rights
+Copyright (c) 2009, Chris Thompson <cpan@cthompson.com>. All rights
 reserved.
 
 This module is free software; you can redistribute it and/or
